Monty Python Flying Circus: Just the Words - Index of Sketches

# Index of Sketches

A B C D E F G H I J K L M N O P Q R S T U V W Y Z

## A |
Accidents involving food | Episode 34
Accidents sketch | Episode 18
Advertisements | Episode 13
After-shave | Episode 17
Agatha Christie sketch | Episode 11
Agatha Christie Sketch (Railway Timetables) | Episode 24
Albatross | Episode 13
Anagram quiz | Episode 30
Ant communication | Episode 41
'Anything Goes In' (song) | Episode 42
Apology | Episode 33
Apology (politicians) | Episode 32
Apology for violence and nudity | Episode 29
Appeal on behalf of extremely rich people | Episode 45
'Archaeology Today' | Episode 21
Architect sketch | Episode 17
Argument clinic | Episode 29
Army captain as clown | Episode 30
Army protection racket | Episode 8
Art critic | Episode 4
Art critic - the place of the nude | Episode 8
Art gallery | Episode 4
Art gallery strike | Episode 25
Arthur 'Two-Sheds' Jackson | Episode 1
Arthur Tree | Episode 10
At home with the ant and other pets | Episode 41
Attila the Bun | Episode 20
'The Attila the Hun Show' | Episode 20
Attila the Nun | Episode 20
The audit | Episode 7
## B |
Bank robber (lingerie shop) | Episode 10
Basingstoke in Westphalia | Episode 42
Batley Townswomen's Guild presents the first heart transplant | Episode 22
Batley Townswomens' Guild presents the Battle of Pearl Harbour | Episode 11
The batsmen of the Kalahari | Episode 45
The Battle of Trafalgar | Episode 11
The BBC is short of money | Episode 28
BBC News (handovers) | Episode 45
BBC programme planners | Episode 38
Beethoven's mynah bird | Episode 21
Bicycle repair man | Episode 3
Biggles dictates a letter | Episode 33
'Bing Tiddle Tiddle Bong' (song) | Episode 22
Bingo-crazed Chinese | Episode 34
A bishop rehearsing | Episode 16
'The Bishop' | Episode 17
'The Black Eagle' | Episode 25
'Blackmail' | Episode 18
Blancmanges playing tennis | Episode 7
Blood donor | Episode 39
'Blood, Devastation, Death, War and Horror' | Episode 30
Bogus psychiatrists | Episode 43
Bomb on plane | Episode 35
'A Book at Bedtime' | Episode 38
Boxing commentary | Episode 43
Boxing match aftermath | Episode 43
'Boxing tonight' - Jack Bodell v. Kenneth Clark | Episode 37
Brigadier and Bishop | Episode 45
The British Well-Basically Club | Episode 35
Bruces | Episode 22
Bull-fighting | Episode 35
Burglar/encyclopedia salesman | Episode 5
Bus conductor sketch | Episode 30
Buying a bed | Episode 8
Buying an ant | Episode 41
## C |
Camel spotting | Episode 7
Camp square-bashing | Episode 22
Careers advisory board | Episode 5
The Cheap-Laughs | Episode 35
Cheese shop | Episode 33
Chemist sketch | Episode 17
Children's interview | Episode 3
Children's stories | Episode 3
A choice of viewing | Episode 17
City gents vox pops | Episode 24
Climbing the north face of the Uxbridge Road | Episode 33
Clodagh Rodgers | Episode 34
Coal mine (historical argument) | Episode 26
Colin Mozart (ratcatcher) | Episode 21
Come back to my place | Episode 13
Commercials | Episode 26
Communist quiz | Episode 25
Complaining about ant | Episode 41
Complaints | Episode 16
Complaints office | Episode 41
Confuse-a-Cat | Episode 5
'Conjuring Today' | Episode 44
Conquistador Coffee Campaign | Episode 24
Cosmetic surgery | Episode 22
Court (phrasebook) | Episode 25
Court scene (charades) | Episode 15
Court scene (Viking) | Episode 27
Court scene (witness in coffin/Cardinal Richelieu) | Episode 3
Court scene - multiple murderer | Episode 27
Courtmartial | Episode 42
'Crackpot Religions Ltd' | Episode 24
Credits of the Year | Episode 39
Cricket match (assegais) | Episode 45
Crossing the Atlantic on a tricycle | Episode 24
Crunchy frog | Episode 6
Current affairs | Episode 18
Cut-price airline | Episode 22
## D |
Déjà vu | Episode 16
'Dad's Doctors' (trail) | Episode 38
'Dad's Pooves' (trail) | Episode 38
David Attenborough | Episode 45
David Niven's fridge | Episode 39
Dead Indian | Episode 19
Dead parrot | Episode 8
The death of Mary Queen of Scots | Episode 22
Dennis Moore | Episode 37
Dennis Moore: Redistibuting the wealth | Episode 37
Dennis Moore: Stealing from the poor | Episode 37
Dentists | Episode 43
Department store | Episode 41
Derby Council v. All Blacks rugby match | Episode 23
Dickie Attenborough | Episode 39
Different endings | Episode 41
Dirty Hungarian phrasebook | Episode 25
The dirty vicar sketch | Episode 39
Doctor | Episode 37
A doctor whose patients are stabbed by his nurse | Episode 45
Documentary on ants | Episode 41
Documentary on boxer | Episode 18
A duck, a cat and a lizard (discussion) | Episode 5
The dull life of a City stockbroker | Episode 6
Dung | Episode 19
## E |
Eighteenth-century social legislation | Episode 11
Election Night Special (Silly and Sensible Parties) | Episode 19
Emigration from Surbiton to Hounslow | Episode 28
The Epsom furniture race | Episode 20
Erizabeth L | Episode 29
Erotic film | Episode 5
Escape (from film) | Episode 18
Europolice Song Contest | Episode 22
Everest climbed by hairdressers | Episode 31
Expedition to Lake Pahoe | Episode 32
Exploding penguin on TV set | Episode 22
Exploding version of 'The Blue Danube' | Episode 26
## F |
'Face the Press' | Episode 14
Falling from building | Episode 12
Famous deaths | Episode 1
Farming club | Episode 28
Father-in-law | Episode 43
Film director (teeth) | Episode 24
Film trailer | Episode 42
'Finian's Rainbow' (starring the man from the off-license) | Episode 19
Fire brigade | Episode 31
The first man to jump the Channel | Episode 10
The first underwater production of 'Measure for Measure' | Episode 22
Fish Licence | Episode 23
Fish-slapping dance | Episode 28
The flasher | Episode 8
Flying lessons | Episode 16
Flying Sheep | Episode 2
Foreign Secretary | Episode 19
Fraud film squad | Episode 29
The free repetition of doubtful words sketch, by an underrated author | Episode 36
French lecture on sheep-aircraft | Episode 2
French subtitled film | Episode 23
The funniest joke in the world | Episode 1
## G |
George III | Episode 40
Gestures to indicate pauses in a televised talk | Episode 30
Girls' boarding school | Episode 26
Gorilla librarian | Episode 10
Gumby brain specialist | Episode 32
Gumby crooner | Episode 9
Gumby flower arranging | Episode 25
## H |
Hamlet and Ophelia | Episode 43
Hell's Grannies | Episode 8
Hermits | Episode 8
Hijacked plane (to Luton) | Episode 16
Historical impersonations | Episode 13
Hitting on the head lessons | Episode 29
Homicidal barber | Episode 9
Hospital for over-actors | Episode 25
Hospital run by RSM | Episode 26
Housing project built by characters from nineteenth-century English literature | Episode 35
How far can a minister fall? | Episode 12
'How not to be seen' | Episode 24
How to feed a goldfish | Episode 26
How to give up being a Mason | Episode 17
'How to recognize different parts of the body' | Episode 22
How to rid the world of all known diseases | Episode 28
Hunting film | Episode 9
## I |
Icelandic Honey Week | Episode 45
Icelandic saga | Episode 27
Ideal Loon Exhibition | Episode 37
The Idiot in Society | Episode 20
'if' - a film by Mr Dibley | Episode 19
Inspector Flying Fox of the Yard | Episode 29
Insurance sketch | Episode 26
Interesting people | Episode 11
Intermissions | Episode 13
International Wife-Swapping | Episode 39
Interruptions | Episode 11
Interview in filing cabinet | Episode 24
'Is there?'...life after death? | Episode 36
'It's a Living' | Episode 19
It's a man's life in the modern army | Episode 4
It's the Arts | Episode 1
'It's the arts' | Episode 6
It's Wolfgang Amadeus Mozart | Episode 1
Italian lesson | Episode 1
## J |
'Jack in a Box' | Episode 34
Job Hunter | Episode 24
Johann Gambolputty.... von Hautkopf of Ulm | Episode 6
Jokes and novelties salesman | Episode 15
Judges | Episode 21
'Julius Caesar' on an Aldis lamp | Episode 15
Jungle restaurant | Episode 29
## K |
Kamikaze Scotsmen | Episode 38
Ken Russell's 'Gardening Club' | Episode 29
Ken Shabby | Episode 12
Kilimanjaro expedition (double vision) | Episode 9
Killer sheep | Episode 20
## L |
Language laboratory | Episode 31
The larch | Episode 3
The last five miles of the M2 | Episode 42
Leapy Lee | Episode 21
Letter (lavatorial humour) | Episode 11
Letters and vox pops | Episode 5
Letters to 'Daily Mirror' | Episode 10
Life and death struggles | Episode 30
'Life of Tschaikowsky' | Episode 28
Lifeboat | Episode 33
Lifeboat (cannibalism) | Episode 26
'Light Entertainment Awards' | Episode 39
Literary football discussion | Episode 11
Live from Epsom | Episode 43
Live from the Grill-o-Mat snack bar, Paignton | Episode 18
Living room on pavement | Episode 17
Llamas | Episode 9
Long John Silver Impersonators v. Bournemouth Gynaecologist | Episode 23
The Lost World of Roiurama | Episode 29
Louis XIV | Episode 40
Lumberjack song | Episode 9
Lupins | Episode 37
## M |
M1 interchange built by characters from 'Paradise Lost' | Episode 35
Man turns into Scotsman | Episode 7
The man who collects birdwatcher's eggs | Episode 26
The man who contradicts people | Episode 22
The man who finishes other peoples sentences | Episode 45
The man who is alternately rude and polite | Episode 18
The man who makes people laugh uncontrollably | Episode 30
The man who says things in a very roundabout way | Episode 26
The man who says words in the wrong order | Episode 36
The man who speaks in anagrams | Episode 30
The man who speaks only the beginnings of words | Episode 26
The man who speaks only the ends of words | Episode 26
The man who speaks only the middles of words | Episode 26
A man with a tape recorder up his brother's nose | Episode 9
A man with a tape recorder up his nose | Episode 9
A man with three buttocks | Episode 2
A man with two noses | Episode 2
Man-powered flight | Episode 15
Marriage guidance counsellor | Episode 2
Mary recruitment office | Episode 30
Me Doctor | Episode 13
Merchant banker | Episode 30
Michaelangelo | Episode 21
The Minehead by-election | Episode 12
The Minister for not listening to people | Episode 32
The Ministry of Silly Walks | Episode 14
Molluscs - 'live' TV documentary | Episode 32
'The Money Programme' | Episode 29
Montgolfier Brothers | Episode 40
Monty Python's Flying Circus again in thirty seconds | Episode 24
'Mortuary Hour' | Episode 35
Mosquito hunters | Episode 21
'Most Awful Family in Britain' | Episode 45
Motor insurance sketch | Episode 17
Mountaineer | Episode 26
The mouse problem | Episode 2
Mr and Mrs Git | Episode 21
Mr Attila the Hun | Episode 13
Mr Hilter | Episode 12
Mr Neutron | Episode 44
Mr Neville Shunt | Episode 24
Mr Pither | Episode 34
Mrs Niggerbaiter explodes | Episode 28
Mrs Premise and Mrs Conclusion visit Jean Paul Satre | Episode 27
Mrs Thing and Mrs Entity | Episode 21
Musical mice | Episode 2
Mystico and Janet - flats built by hypnosis | Episode 35
## N |
A naked man | Episode 35
'Nationwide' | Episode 43
Naughty bits | Episode 22
Neurotic announcers | Episode 30
New brain from Curry's | Episode 39
New cooker sketch | Episode 14
The news for gibbons | Episode 20
The news for parrots | Episode 20
The news for wombats | Episode 20
The news with Richard Baker | Episode 33
The news with Richard Baker | Episode 30
Newsflash (germans) | Episode 42
Newsreader arrested | Episode 5
No time to lose | Episode 38
Non-illegal robbery | Episode 6
Nudge nudge | Episode 3
## O |
Off-Licence | Episode 37
Old lady snoopers | Episode 33
The Olympic hide-and-seek final | Episode 35
One more minute of Monty Python's Flying Circus | Episode 29
Operating theatre (squatters) | Episode 13
The Oscar Wilde sketch | Episode 39
Our Eamonn | Episode 31
## P |
'The Pantomime Horse is a Secret Agent' | Episode 30
Pantomime horses | Episode 30
'Party Hints' with Veronica Smalls | Episode 31
Party Political Broadcast (choreographed) | Episode 38
Party Political Broadcast on Behalf of the Norwegian Party | Episode 40
Pasolini's film 'The Third Test Match' | Episode 39
Penguins | Episode 38
Pet conversions | Episode 10
Philip Jenkinson on Cheese Westerns | Episode 33
Photos of Uncle Ted (Spanish Inquisition) | Episode 15
Picasso/cycling race | Episode 1
The Piranha brothers | Episode 14
Piston engine (a bargain) | Episode 43
The Poet McTeagle | Episode 16
Poetry reading (ants) | Episode 41
Poets | Episode 17
Police Constable Pan-Am | Episode 17
Police helmets | Episode 43
Police raid | Episode 5
Police station | Episode 7
Police station (silly voices) | Episode 12
Policemen make wonderful friends | Episode 6
Poofy judges | Episode 21
Pornographic bookshop | Episode 36
Post box ceremony | Episode 44
'Prejudice' | Episode 37
Prices on the planet Algon | Episode 35
'Probe-around' on crime | Episode 13
Programme titles conference | Episode 42
Psychiatrist milkman | Episode 16
Psychiatry - silly sketch | Episode 13
The public are idiots | Episode 42
Puss in Boots | Episode 28
## Q |
Queen Victoria Handicap | Episode 43
The Queen will be watching | Episode 26
Quiz programme - 'Wishes' | Episode 13
## R |
RAF banter | Episode 42
Ramsay MacDonald striptease | Episode 24
Ratcatcher | Episode 20
Raymond Luxury Yacht interview | Episode 19
'Rear Window' - a film by Mr Dibley | Episode 19
Red Indian in theatre | Episode 6
'Redgauntlet' | Episode 38
The refreshment room at Bletchley | Episode 9
Registrar (wife swap) | Episode 21
Registry office | Episode 19
Repeating groove | Episode 24
Restaurant (abuse/cannibalism) | Episode 13
Restaurant sketch | Episode 3
Rival documentaries | Episode 38
A room in Polonius's house | Episode 43
'Russian 42nd International Clambake' | Episode 34
## S |
Salvation fuzz | Episode 29
Sam Peckinpah's 'Salad Days' | Episode 33
School prize-giving | Episode 19
Schoolboys' Life Assurance Company | Episode 28
Science fiction sketch | Episode 7
A Scotsman on a horse | Episode 6
A Scotsman on a horse | Episode 2
Scott of the Antarctic | Episode 23
Scott of the Sahara | Episode 23
Seashore interlude film | Episode 33
Secret Service dentists | Episode 4
Secretary of State striptease | Episode 20
Seduced milkmen | Episode 3
Self-defence | Episode 4
The semaphore version of 'Wuthering Heights' | Episode 15
Seven Brides for Seven Brothers | Episode 18
Shakespeare | Episode 21
Sherry-drinking vicar | Episode 36
The show so far | Episode 33
Show-jumping (musical) | Episode 42
The silliest interview we've ever had | Episode 32
The silliest sketch we've ever done | Episode 32
Silly disturbances (the Rev. Arthur Belling) | Episode 36
Silly doctor sketch (immediately abandoned) | Episode 21
Silly job interview | Episode 5
Silly noises | Episode 36
Silly vicar | Episode 21
Six more minutes of Monty Python's Flying Circus | Episode 29
Smolensk | Episode 34
The smuggler | Episode 5
Society for Putting Things on top of Other Things | Episode 18
Song ('And did those feet') | Episode 4
Spam | Episode 25
The Spanish Inquisition | Episode 15
'Spectrum' - talking about things | Episode 12
'Spot the Loony' | Episode 38
Stock Exchange report | Episode 27
Stolen newsreader | Episode 3
Stonehenge | Episode 13
'Storage jars' | Episode 33
Strangers in the night | Episode 10
Submarine | Episode 26
'Summarize Proust Competition' | Episode 31
## T |
'Take Your Pick' | Episode 20
Tax on thingy | Episode 15
Teddy Salad (CIA agent) | Episode 44
Ten seconds of sex | Episode 35
Test match | Episode 20
Thames TV introduction | Episode 39
Theory on Brontosauruses by Anne Elk (Miss) | Episode 31
'There is nothing quite so wonderful as money' (song) | Episode 29
There's been a murder | Episode 22
Thripshaw's disease | Episode 36
The time on BBC 1 | Episode 19
Timmy Williams interview | Episode 19
Tobacconists (prostitute advert) | Episode 14
Today in Parliament | Episode 20
Tory Housewives Clean-up Campaign | Episode 32
Toupee | Episode 41
Trailer | Episode 21
Trailer | Episode 10
Travel agent | Episode 31
Trim-Jeans Theatre | Episode 28
Trivializing the war | Episode 42
Trotsky | Episode 34
Tudor job agency | Episode 36
Tuesday documentary/children's story/party political broadcast | Episode 32
Tunnelling from Godalming to Java | Episode 10
'TV4 or not TV4' diskussion | Episode 37
Twentieth-century vole | Episode 6
## U |
Undertaker's sketch | Episode 26
Undertakers film | Episode 11
Undertakers film | Episode 11
Undressing in public | Episode 4
Unexploded Scotsman | Episode 38
'Up Your Pavement' | Episode 42
Upperclass Twit of the Year | Episode 12
## V |
Vicar/salesman | Episode 28
The visitors | Episode 9
Visitors from Coventry | Episode 12
Vocational Guidance Counseller (chartered accountant) | Episode 10
Vox pops | Episode 6
Vox pops on aftershave | Episode 17
Vox pops on full frontal nudity | Episode 8
Vox pops on politicians | Episode 20
Vox pops on smuggling | Episode 5
Vox pops on tax | Episode 15
## W |
The wacky queen | Episode 2
Wainscotting | Episode 20
Walk-on part in sketch | Episode 10
The walking tree of Dahomey | Episode 45
Watney's Red Barrel | Episode 31
What the stars foretell | Episode 37
'When Does A Dream Begin?' (song) | Episode 42
Whicker Island | Episode 27
Whizzo butter | Episode 1
Woody and tinny words | Episode 42
Words not to be used again | Episode 17
Working-class playwright | Episode 2
World War One | Episode 28
The wrestling epilogue | Episode 2
## Y |
You're no fun any more | Episode 7
'Ypres 1914' | Episode 25
'Ypres 1914' - abandoned | Episode 25
'Yummy yummy' | Episode 24
## Z |
Zeppelin | Episode 40